@@ -464,7 +464,7 @@ sub create_watch {
     # try to take advantage of GitHub's release page, since mode=git
     # is much more taxing for QA team's servers
     if ( $upstream_url =~ m<github\.com/([^/]+)/([^/]+)> ||
-         $upstream_url =~ m<\@github\.com:([^/]+)/([^/+])> ) {
+         $upstream_url =~ m<\@github\.com:([^/]+)/([^/]+)> ) {
         my $owner = $1;
         my $project = $2;
         $project =~ s/.git\z//;
